# Phyme
Phyme is a Python rhyming dictionary for songwriting, currently under active development.


Pronunciation is taken from [The CMU Pronouncing Dictionary](http://www.speech.cs.cmu.edu/cgi-bin/cmudict). Some background information on rhyming for songwriting can be found [here](http://songchops.com/2013/10/rhyme-families-your-secret-weapon/).